==> openshift-model-operator-5.11.1-sources.jar: io/fabric8/openshift/api/model/operator/v1/ClientTLSFluentImpl.java <==
package io.fabric8.openshift.api.model.operator.v1;

import io.fabric8.openshift.api.model.ConfigMapNameReferenceFluentImpl;
import io.fabric8.openshift.api.model.ConfigMapNameReferenceBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.openshift.api.model.ConfigMapNameReference;
import java.util.Map;

 /**
  * Generated
  */
public class ClientTLSFluentImpl<A extends io.fabric8.openshift.api.model.operator.v1.ClientTLSFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.operator.v1.ClientTLSFluent<A>{
  public ClientTLSFluentImpl() {
  }
  public ClientTLSFluentImpl(io.fabric8.openshift.api.model.operator.v1.ClientTLS instance) {
    this.withAllowedSubjectPatterns(instance.getAllowedSubjectPatterns()); 
    this.withClientCA(instance.getClientCA()); 
    this.withClientCertificatePolicy(instance.getClientCertificatePolicy()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.util.List<java.lang.String> allowedSubjectPatterns = new java.util.ArrayList<java.lang.String>();
  private io.fabric8.openshift.api.model.ConfigMapNameReferenceBuilder clientCA;
  private java.lang.String clientCertificatePolicy;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public A addToAllowedSubjectPatterns(java.lang.Integer index,java.lang.String item) {
    if (this.allowedSubjectPatterns == null) {this.allowedSubjectPatterns = new java.util.ArrayList<java.lang.String>();}
    this.allowedSubjectPatterns.add(index, item);
    return (A)this;
  }
  public A setToAllowedSubjectPatterns(java.lang.Integer index,java.lang.String item) {
    if (this.allowedSubjectPatterns == null) {this.allowedSubjectPatterns = new java.util.ArrayList<java.lang.String>();}
    this.allowedSubjectPatterns.set(index, item); return (A)this;
  }
  public A addToAllowedSubjectPatterns(java.lang.String... items) {
    if (this.allowedSubjectPatterns == null) {this.allowedSubjectPatterns = new java.util.ArrayList<java.lang.String>();}
    for (java.lang.String item : items) {this.allowedSubjectPatterns.add(item);} return (A)this;
  }
  public A addAllToAllowedSubjectPatterns(java.util.Collection<java.lang.String> items) {
    if (this.allowedSubjectPatterns == null) {this.allowedSubjectPatterns = new java.util.ArrayList<java.lang.String>();}
    for (java.lang.String item : items) {this.allowedSubjectPatterns.add(item);} return (A)this;
  }
  public A removeFromAllowedSubjectPatterns(java.lang.String... items) {
    for (java.lang.String item : items) {if (this.allowedSubjectPatterns!= null){ this.allowedSubjectPatterns.remove(item);}} return (A)this;
  }
  public A removeAllFromAllowedSubjectPatterns(java.util.Collection<java.lang.String> items) {
    for (java.lang.String item : items) {if (this.allowedSubjectPatterns!= null){ this.allowedSubjectPatterns.remove(item);}} return (A)this;
  }
  public java.util.List<java.lang.String> getAllowedSubjectPatterns() {
    return this.allowedSubjectPatterns;
  }
  public java.lang.String getAllowedSubjectPattern(java.lang.Integer index) {
    return this.allowedSubjectPatterns.get(index);
  }
  public java.lang.String getFirstAllowedSubjectPattern() {
    return this.allowedSubjectPatterns.get(0);
  }
  public java.lang.String getLastAllowedSubjectPattern() {
    return this.allowedSubjectPatterns.get(allowedSubjectPatterns.size() - 1);
  }
  public java.lang.String getMatchingAllowedSubjectPattern(java.util.function.Predicate<java.lang.String> predicate) {
    for (java.lang.String item: allowedSubjectPatterns) { if(predicate.test(item)){ return item;} } return null;
  }
  public java.lang.Boolean hasMatchingAllowedSubjectPattern(java.util.function.Predicate<java.lang.String> predicate) {
    for (java.lang.String item: allowedSubjectPatterns) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withAllowedSubjectPatterns(java.util.List<java.lang.String> allowedSubjectPatterns) {
    if (allowedSubjectPatterns != null) {this.allowedSubjectPatterns = new java.util.ArrayList<java.lang.String>(); for (java.lang.String item : allowedSubjectPatterns){this.addToAllowedSubjectPatterns(item);}} else { this.allowedSubjectPatterns = null;} return (A) this;
  }
  public A withAllowedSubjectPatterns(java.lang.String... allowedSubjectPatterns) {
    if (this.allowedSubjectPatterns != null) {this.allowedSubjectPatterns.clear();}
    if (allowedSubjectPatterns != null) {for (java.lang.String item :allowedSubjectPatterns){ this.addToAllowedSubjectPatterns(item);}} return (A) this;
  }
  public java.lang.Boolean hasAllowedSubjectPatterns() {
    return allowedSubjectPatterns != null && !allowedSubjectPatterns.isEmpty();
  }
  public A addNewAllowedSubjectPattern(java.lang.String arg0) {
    return (A)addToAllowedSubjectPatterns(new String(arg0));
  }
  
  /**
   * This method has been deprecated, please use method buildClientCA instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.ConfigMapNameReference getClientCA() {
    return this.clientCA!=null?this.clientCA.build():null;
  }
  public io.fabric8.openshift.api.model.ConfigMapNameReference buildClientCA() {
    return this.clientCA!=null?this.clientCA.build():null;
  }
  public A withClientCA(io.fabric8.openshift.api.model.ConfigMapNameReference clientCA) {
    _visitables.get("clientCA").remove(this.clientCA);
    if (clientCA!=null){ this.clientCA= new io.fabric8.openshift.api.model.ConfigMapNameReferenceBuilder(clientCA); _visitables.get("clientCA").add(this.clientCA);} return (A) this;
  }
  public java.lang.Boolean hasClientCA() {
    return this.clientCA != null;
  }
  public A withNewClientCA(java.lang.String name) {
    return (A)withClientCA(new ConfigMapNameReference(name));
  }
  public io.fabric8.openshift.api.model.operator.v1.ClientTLSFluent.ClientCANested<A> withNewClientCA() {
    return new io.fabric8.openshift.api.model.operator.v1.ClientTLSFluentImpl.ClientCANestedImpl();
  }
  public io.fabric8.openshift.api.model.operator.v1.ClientTLSFluent.ClientCANested<A> withNewClientCALike(io.fabric8.openshift.api.model.ConfigMapNameReference item) {
    return new io.fabric8.openshift.api.model.operator.v1.ClientTLSFluentImpl.ClientCANestedImpl(item);
  }
  public io.fabric8.openshift.api.model.operator.v1.ClientTLSFluent.ClientCANested<A> editClientCA() {
    return withNewClientCALike(getClientCA());
  }
  public io.fabric8.openshift.api.model.operator.v1.ClientTLSFluent.ClientCANested<A> editOrNewClientCA() {
    return withNewClientCALike(getClientCA() != null ? getClientCA(): new io.fabric8.openshift.api.model.ConfigMapNameReferenceBuilder().build());
  }
  public io.fabric8.openshift.api.model.operator.v1.ClientTLSFluent.ClientCANested<A> editOrNewClientCALike(io.fabric8.openshift.api.model.ConfigMapNameReference item) {
    return withNewClientCALike(getClientCA() != null ? getClientCA(): item);
  }
  public java.lang.String getClientCertificatePolicy() {
    return this.clientCertificatePolicy;
  }
  public A withClientCertificatePolicy(java.lang.String clientCertificatePolicy) {
    this.clientCertificatePolicy=clientCertificatePolicy; return (A) this;
  }
  public java.lang.Boolean hasClientCertificatePolicy() {
    return this.clientCertificatePolicy != null;
  }
  
  /**
   * Method is deprecated. use withClientCertificatePolicy instead.
   */
  @java.lang.Deprecated
  public A withNewClientCertificatePolicy(java.lang.String arg0) {
    return (A)withClientCertificatePolicy(new String(arg0));
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ClientTLSFluentImpl that = (ClientTLSFluentImpl) o;
    if (allowedSubjectPatterns != null ? !allowedSubjectPatterns.equals(that.allowedSubjectPatterns) :that.allowedSubjectPatterns != null) return false;
    if (clientCA != null ? !clientCA.equals(that.clientCA) :that.clientCA != null) return false;
    if (clientCertificatePolicy != null ? !clientCertificatePolicy.equals(that.clientCertificatePolicy) :that.clientCertificatePolicy != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(allowedSubjectPatterns,  clientCA,  clientCertificatePolicy,  additionalProperties,  super.hashCode());
  }
  public class ClientCANestedImpl<N> extends io.fabric8.openshift.api.model.ConfigMapNameReferenceFluentImpl<io.fabric8.openshift.api.model.operator.v1.ClientTLSFluent.ClientCANested<N>> implements io.fabric8.openshift.api.model.operator.v1.ClientTLSFluent.ClientCANested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    ClientCANestedImpl(io.fabric8.openshift.api.model.ConfigMapNameReference item) {
      this.builder = new io.fabric8.openshift.api.model.ConfigMapNameReferenceBuilder(this, item);
    }
    ClientCANestedImpl() {
      this.builder = new io.fabric8.openshift.api.model.ConfigMapNameReferenceBuilder(this);
    }
    io.fabric8.openshift.api.model.ConfigMapNameReferenceBuilder builder;
    public N and() {
      return (N) ClientTLSFluentImpl.this.withClientCA(builder.build());
    }
    public N endClientCA() {
      return and();
    }
    
  }
  
}

==> openshift-model-operator-5.12.4-sources.jar: io/fabric8/openshift/api/model/operator/v1/ClientTLSFluentImpl.java <==
package io.fabric8.openshift.api.model.operator.v1;

import io.fabric8.openshift.api.model.ConfigMapNameReferenceFluentImpl;
import io.fabric8.openshift.api.model.ConfigMapNameReferenceBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.openshift.api.model.ConfigMapNameReference;
import java.util.Map;

 /**
  * Generated
  */
public class ClientTLSFluentImpl<A extends io.fabric8.openshift.api.model.operator.v1.ClientTLSFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.operator.v1.ClientTLSFluent<A>{
  public ClientTLSFluentImpl() {
  }
  public ClientTLSFluentImpl(io.fabric8.openshift.api.model.operator.v1.ClientTLS instance) {
    this.withAllowedSubjectPatterns(instance.getAllowedSubjectPatterns()); 
    this.withClientCA(instance.getClientCA()); 
    this.withClientCertificatePolicy(instance.getClientCertificatePolicy()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.util.List<java.lang.String> allowedSubjectPatterns = new java.util.ArrayList<java.lang.String>();
  private io.fabric8.openshift.api.model.ConfigMapNameReferenceBuilder clientCA;
  private java.lang.String clientCertificatePolicy;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public A addToAllowedSubjectPatterns(java.lang.Integer index,java.lang.String item) {
    if (this.allowedSubjectPatterns == null) {this.allowedSubjectPatterns = new java.util.ArrayList<java.lang.String>();}
    this.allowedSubjectPatterns.add(index, item);
    return (A)this;
  }
  public A setToAllowedSubjectPatterns(java.lang.Integer index,java.lang.String item) {
    if (this.allowedSubjectPatterns == null) {this.allowedSubjectPatterns = new java.util.ArrayList<java.lang.String>();}
    this.allowedSubjectPatterns.set(index, item); return (A)this;
  }
  public A addToAllowedSubjectPatterns(java.lang.String... items) {
    if (this.allowedSubjectPatterns == null) {this.allowedSubjectPatterns = new java.util.ArrayList<java.lang.String>();}
    for (java.lang.String item : items) {this.allowedSubjectPatterns.add(item);} return (A)this;
  }
  public A addAllToAllowedSubjectPatterns(java.util.Collection<java.lang.String> items) {
    if (this.allowedSubjectPatterns == null) {this.allowedSubjectPatterns = new java.util.ArrayList<java.lang.String>();}
    for (java.lang.String item : items) {this.allowedSubjectPatterns.add(item);} return (A)this;
  }
  public A removeFromAllowedSubjectPatterns(java.lang.String... items) {
    for (java.lang.String item : items) {if (this.allowedSubjectPatterns!= null){ this.allowedSubjectPatterns.remove(item);}} return (A)this;
  }
  public A removeAllFromAllowedSubjectPatterns(java.util.Collection<java.lang.String> items) {
    for (java.lang.String item : items) {if (this.allowedSubjectPatterns!= null){ this.allowedSubjectPatterns.remove(item);}} return (A)this;
  }
  public java.util.List<java.lang.String> getAllowedSubjectPatterns() {
    return this.allowedSubjectPatterns;
  }
  public java.lang.String getAllowedSubjectPattern(java.lang.Integer index) {
    return this.allowedSubjectPatterns.get(index);
  }
  public java.lang.String getFirstAllowedSubjectPattern() {
    return this.allowedSubjectPatterns.get(0);
  }
  public java.lang.String getLastAllowedSubjectPattern() {
    return this.allowedSubjectPatterns.get(allowedSubjectPatterns.size() - 1);
  }
  public java.lang.String getMatchingAllowedSubjectPattern(java.util.function.Predicate<java.lang.String> predicate) {
    for (java.lang.String item: allowedSubjectPatterns) { if(predicate.test(item)){ return item;} } return null;
  }
  public java.lang.Boolean hasMatchingAllowedSubjectPattern(java.util.function.Predicate<java.lang.String> predicate) {
    for (java.lang.String item: allowedSubjectPatterns) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withAllowedSubjectPatterns(java.util.List<java.lang.String> allowedSubjectPatterns) {
    if (allowedSubjectPatterns != null) {this.allowedSubjectPatterns = new java.util.ArrayList(); for (java.lang.String item : allowedSubjectPatterns){this.addToAllowedSubjectPatterns(item);}} else { this.allowedSubjectPatterns = null;} return (A) this;
  }
  public A withAllowedSubjectPatterns(java.lang.String... allowedSubjectPatterns) {
    if (this.allowedSubjectPatterns != null) {this.allowedSubjectPatterns.clear();}
    if (allowedSubjectPatterns != null) {for (java.lang.String item :allowedSubjectPatterns){ this.addToAllowedSubjectPatterns(item);}} return (A) this;
  }
  public java.lang.Boolean hasAllowedSubjectPatterns() {
    return allowedSubjectPatterns != null && !allowedSubjectPatterns.isEmpty();
  }
  public A addNewAllowedSubjectPattern(java.lang.String arg0) {
    return (A)addToAllowedSubjectPatterns(new String(arg0));
  }
  
  /**
   * This method has been deprecated, please use method buildClientCA instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.ConfigMapNameReference getClientCA() {
    return this.clientCA!=null?this.clientCA.build():null;
  }
  public io.fabric8.openshift.api.model.ConfigMapNameReference buildClientCA() {
    return this.clientCA!=null?this.clientCA.build():null;
  }
  public A withClientCA(io.fabric8.openshift.api.model.ConfigMapNameReference clientCA) {
    _visitables.get("clientCA").remove(this.clientCA);
    if (clientCA!=null){ this.clientCA= new io.fabric8.openshift.api.model.ConfigMapNameReferenceBuilder(clientCA); _visitables.get("clientCA").add(this.clientCA);} return (A) this;
  }
  public java.lang.Boolean hasClientCA() {
    return this.clientCA != null;
  }
  public A withNewClientCA(java.lang.String name) {
    return (A)withClientCA(new ConfigMapNameReference(name));
  }
  public io.fabric8.openshift.api.model.operator.v1.ClientTLSFluent.ClientCANested<A> withNewClientCA() {
    return new io.fabric8.openshift.api.model.operator.v1.ClientTLSFluentImpl.ClientCANestedImpl();
  }
  public io.fabric8.openshift.api.model.operator.v1.ClientTLSFluent.ClientCANested<A> withNewClientCALike(io.fabric8.openshift.api.model.ConfigMapNameReference item) {
    return new io.fabric8.openshift.api.model.operator.v1.ClientTLSFluentImpl.ClientCANestedImpl(item);
  }
  public io.fabric8.openshift.api.model.operator.v1.ClientTLSFluent.ClientCANested<A> editClientCA() {
    return withNewClientCALike(getClientCA());
  }
  public io.fabric8.openshift.api.model.operator.v1.ClientTLSFluent.ClientCANested<A> editOrNewClientCA() {
    return withNewClientCALike(getClientCA() != null ? getClientCA(): new io.fabric8.openshift.api.model.ConfigMapNameReferenceBuilder().build());
  }
  public io.fabric8.openshift.api.model.operator.v1.ClientTLSFluent.ClientCANested<A> editOrNewClientCALike(io.fabric8.openshift.api.model.ConfigMapNameReference item) {
    return withNewClientCALike(getClientCA() != null ? getClientCA(): item);
  }
  public java.lang.String getClientCertificatePolicy() {
    return this.clientCertificatePolicy;
  }
  public A withClientCertificatePolicy(java.lang.String clientCertificatePolicy) {
    this.clientCertificatePolicy=clientCertificatePolicy; return (A) this;
  }
  public java.lang.Boolean hasClientCertificatePolicy() {
    return this.clientCertificatePolicy != null;
  }
  
  /**
   * Method is deprecated. use withClientCertificatePolicy instead.
   */
  @java.lang.Deprecated
  public A withNewClientCertificatePolicy(java.lang.String arg0) {
    return (A)withClientCertificatePolicy(new String(arg0));
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ClientTLSFluentImpl that = (ClientTLSFluentImpl) o;
    if (allowedSubjectPatterns != null ? !allowedSubjectPatterns.equals(that.allowedSubjectPatterns) :that.allowedSubjectPatterns != null) return false;
    if (clientCA != null ? !clientCA.equals(that.clientCA) :that.clientCA != null) return false;
    if (clientCertificatePolicy != null ? !clientCertificatePolicy.equals(that.clientCertificatePolicy) :that.clientCertificatePolicy != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(allowedSubjectPatterns,  clientCA,  clientCertificatePolicy,  additionalProperties,  super.hashCode());
  }
  public class ClientCANestedImpl<N> extends io.fabric8.openshift.api.model.ConfigMapNameReferenceFluentImpl<io.fabric8.openshift.api.model.operator.v1.ClientTLSFluent.ClientCANested<N>> implements io.fabric8.openshift.api.model.operator.v1.ClientTLSFluent.ClientCANested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    ClientCANestedImpl(io.fabric8.openshift.api.model.ConfigMapNameReference item) {
      this.builder = new io.fabric8.openshift.api.model.ConfigMapNameReferenceBuilder(this, item);
    }
    ClientCANestedImpl() {
      this.builder = new io.fabric8.openshift.api.model.ConfigMapNameReferenceBuilder(this);
    }
    io.fabric8.openshift.api.model.ConfigMapNameReferenceBuilder builder;
    public N and() {
      return (N) ClientTLSFluentImpl.this.withClientCA(builder.build());
    }
    public N endClientCA() {
      return and();
    }
    
  }
  
}
